#
# spec file for package zaz
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           zaz
Version:        1.0.1
Release:        3.7
Summary:        Puzzle game about arranging balls in triplets
License:        GPL-3.0-or-later
Group:          Amusements/Games/Logic
URL:            https://zaz.sourceforge.net/
Source0:        http://downloads.sourceforge.net/%{name}/%{name}-%{version}.tar.gz
# PATCH-FIX-OPENSUSE - zaz-extra_zaz.desktop.patch -- Add GenericName
Patch0:         %{name}-extra_zaz.desktop.patch
BuildRequires:  Mesa-devel
BuildRequires:  dos2unix
BuildRequires:  gcc-c++
BuildRequires:  gettext-tools
BuildRequires:  opengl-games-utils
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(SDL_image)
BuildRequires:  pkgconfig(ftgl)
BuildRequires:  pkgconfig(sdl)
BuildRequires:  pkgconfig(theora)
BuildRequires:  pkgconfig(vorbis)
Requires:       opengl-games-utils

%description
Zaz (Zaz ain't Z***) is a game where the player has to get rid of
incoming balls by arranging them in triplets. The idea of the game
is loosely based on games like Luxor, Zuma and Puzzle Bobble.
The twists that make Zaz stand out from other games of this type are
that the balls have to be picked from the path
(insted of being randomly assigned for the player) and that
the player's "vehicle" is also attached to a path which is different
from level to level.
A 3D accelerator is needed for decent gameplay.

%prep
%autosetup -p0

# Convert to unix line end
find -name "*.rc" -print0 -or -name "*.cpp" -print0 -or -name "*.h" -print0 | xargs -0 dos2unix

# Correct Permissions
chmod 0644 extra/%{name}.desktop

%build
%configure --docdir=%{_defaultdocdir}/%{name}
%make_build

%install
%make_install

# Remove useless Documentation or license (we install manually)
rm -f %{buildroot}%{_docdir}/%{name}/{INSTALL,NEWS,COPYING}
# symlink OpenGL Wrapper
ln -s opengl-game-wrapper.sh %{buildroot}%{_bindir}/%{name}-wrapper

%suse_update_desktop_file %{name}

%find_lang %{name}

%files -f %{name}.lang
%license COPYING
%doc AUTHORS ChangeLog README
%{_bindir}/%{name}
%{_bindir}/%{name}-wrapper
%{_datadir}/applications/%{name}.desktop
%{_datadir}/pixmaps/%{name}.xpm
%{_datadir}/%{name}

%changelog
* Tue Feb 20 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN.
* Wed Nov 23 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Homepage link http://zaz.sourceforge.net/ is a permanent redirect
  to its HTTPS counterpart https://zaz.sourceforge.net/
* Mon Apr 26 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 1.0.1
  * splash off by default
  * fixed build scripts
* Mon Mar 29 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Cleaned spec file, fixed Factory build
* Wed Oct  7 2015 nemysis@openSUSE.org
- Modernize spec
- Remove leading article from Summary
- Change Group
- Change Source0 to use Web URL
- Remove Desktop entry file, use supplied
- Add patch zaz-extra_zaz.desktop.patch, Add GenericName
- Add BuildRequires for dos2unix
- Use BuildRequires pkgconfig() instead of devel packages
- Use check for openSUSE %%if 0%%{?suse_version} <= 1320 for ftgl-devel
- Add Requires for opengl-games-utils
- Change Description
- Remove export SUSE_ASNEEDED=0
- Change %%configure options
- Correct Permissions for zaz.desktop
- Change Documentation, use default
* Sun Feb 19 2012 jengelh@medozas.de
- Remove redundant tags/sections from specfile
- Set License field to SPDX format
* Wed Nov 23 2011 PVince81@opensuse.org
- Fixed linkage error in openSUSE 12.1
* Sat Sep  4 2010 PVince81@yahoo.fr
- updated to version 1.0.0
* Mon Jul 26 2010 PVince81@yahoo.fr
- updated to version 0.8.0
* Sat May  8 2010 PVince81@yahoo.fr
- updated to version 0.7.0
* Sun Feb 21 2010 prusnak@suse.cz
- updated to 0.3.3
* Sat Aug 29 2009 prusnak@suse.cz
- don't strip the binary
* Fri Aug 28 2009 PVince81@yahoo.fr
- Initial package
